Changelog
=========

0.0.4 (2021-05-27)
------------------

* Fix length of url_hash field
* Fix packaging to include migrations


0.0.3 (2021-03-11)
------------------

* Add support for embedding and linking external stories without importing
* Make `BaseWebStoryPage` functionality available through a mixin class `WebStoryPageMixin`


0.0.2 (2021-03-02)
------------------

* Allow disabling HTML cleaning with `WAGTAIL_WEBSTORIES_IMPORT_MODEL`


0.0.1 (2020-12-07)
------------------

* Initial release
